aboutsummaryrefslogtreecommitdiffstats
path: root/components/script/dom/xrreferencespace.rs
diff options
context:
space:
mode:
authorManish Goregaokar <manishsmail@gmail.com>2019-04-04 14:50:23 -0700
committerManish Goregaokar <manishsmail@gmail.com>2019-04-04 14:50:23 -0700
commitd2e2b8da4da132390225ffc85adb8a33a1b36c13 (patch)
tree286b875466226f64aec70d05fa24a4bdeed7de43 /components/script/dom/xrreferencespace.rs
parentf1b82f8573d825a40e4fe0d32559b1acb169ac9c (diff)
downloadservo-d2e2b8da4da132390225ffc85adb8a33a1b36c13.tar.gz
servo-d2e2b8da4da132390225ffc85adb8a33a1b36c13.zip
Rename incorrectly-named get_pose methods
Diffstat (limited to 'components/script/dom/xrreferencespace.rs')
-rw-r--r--components/script/dom/xrreferencespace.rs19
1 files changed, 14 insertions, 5 deletions
diff --git a/components/script/dom/xrreferencespace.rs b/components/script/dom/xrreferencespace.rs
index ed42d63b4be..ce81a714e80 100644
--- a/components/script/dom/xrreferencespace.rs
+++ b/components/script/dom/xrreferencespace.rs
@@ -54,9 +54,9 @@ impl XRReferenceSpaceMethods for XRReferenceSpace {
}
impl XRReferenceSpace {
- /// Gets viewer pose represented by this space
+ /// Gets pose of the viewer with respect to this space
pub fn get_viewer_pose(&self, base_pose: &WebVRFrameData) -> RigidTransform3D<f64> {
- let pose = self.get_pose(base_pose);
+ let pose = self.get_unoffset_viewer_pose(base_pose);
// This may change, see https://github.com/immersive-web/webxr/issues/567
let offset = self.transform.get().transform();
@@ -64,16 +64,25 @@ impl XRReferenceSpace {
inverse.pre_mul(&pose)
}
/// Gets pose represented by this space
///
/// Does not apply originOffset, use get_viewer_pose instead if you need it
- pub fn get_pose(&self, base_pose: &WebVRFrameData) -> RigidTransform3D<f64> {
+ pub fn get_unoffset_viewer_pose(&self, base_pose: &WebVRFrameData) -> RigidTransform3D<f64> {
if let Some(stationary) = self.downcast::<XRStationaryReferenceSpace>() {
- stationary.get_pose(base_pose)
+ stationary.get_unoffset_viewer_pose(base_pose)
} else {
// non-subclassed XRReferenceSpaces exist, obtained via the "identity"
// type. The pose does not depend on the base pose.
RigidTransform3D::identity()
}
}
+
+ /// Gets pose represented by this space
+ ///
+ /// The reference origin used is common between all
+ /// get_pose calls for spaces from the same device, so this can be used to compare
+ /// with other spaces
+ pub fn get_pose(&self, _: &WebVRFrameData) -> RigidTransform3D<f64> {
+ unimplemented!()
+ }
}
@@ -64,16 +64,25 @@ impl XRReferenceSpace {
inverse.pre_mul(&pose)
}
- /// Gets pose represented by this space
+ /// Gets pose of the viewer with respect to this space
///
/// Does not apply originOffset, use get_viewer_pose instead if you need it